@@ -8,5 +8,5 @@ Attributes:
 
 from typing import Callable, List, Union
 
-CmdType = Union[str, List[str]]
-CmdFuncType = Union[CmdType, Callable]
+CmdType = Union[str, List[str]]  # noqa: E1136 (bug on Python 3.9)
+CmdFuncType = Union[CmdType, Callable]  # noqa: E1136 (bug on Python 3.9)
